#[non_exhaustive]pub enum AgentAction {
Respond {
output: RunOutput,
},
RequestModel {
request: ModelRequest,
},
RequestEffect {
request: EffectRequest,
},
RequestEffects {
requests: Vec<EffectRequest>,
},
}Expand description
Next action requested by a step-wise agent kernel.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Respond
The run is complete.
RequestModel
The outer runtime should execute a provider request and feed back
Observation::Model.
Fields

request: ModelRequestProvider request.
RequestEffect
The outer runtime should govern and execute an effect request, then
feed back Observation::Effect.
Fields

request: EffectRequestEffect request.
RequestEffects
The outer runtime should govern and execute multiple effect requests,
then feed back Observation::Effects.
Fields

requests: Vec<EffectRequest>Effect requests.