#[non_exhaustive]pub enum ToolMemoryPolicy {
Normal,
Protected,
}Expand description
Memory handling policy for model-visible tool/effect output.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Normal
Record normally.
Protected
Record as protected memory when supported by the memory implementation.
Implementations
Sourceimpl ToolMemoryPolicy
impl ToolMemoryPolicy
Sourcepub fn is_protected(self) -> bool
pub fn is_protected(self) -> bool
Whether the output should be recorded as protected memory.