Crate molo_core

Crate molo_core 

Core protocol types and traits for molo.

Re-exports

pub use agent::AgentAction;
pub use agent::ModelObservation;
pub use agent::ModelRequest;
pub use agent::Observation;
pub use effect::DisplayFormat;
pub use effect::DisplayOutput;
pub use effect::EffectKind;
pub use effect::EffectObservation;
pub use effect::EffectOutput;
pub use effect::EffectRequest;
pub use effect::EffectSource;
pub use effect::EffectStatus;
pub use effect::RiskLevel;
pub use message::ContentBlock;
pub use message::ImageContent;
pub use message::Message;
pub use message::ToolCall;
pub use observability::AgentEventRecord;
pub use observability::EventSeverity;
pub use observability::RedactionRecord;
pub use provider::Backoff;
pub use provider::ChatRequest;
pub use provider::ChatResponse;
pub use provider::FakeProvider;
pub use provider::FakeReply;
pub use provider::FinishReason;
pub use provider::ModelOptions;
pub use provider::Provider;
pub use provider::ProviderCapabilities;
pub use provider::ProviderError;
pub use provider::ProviderRequestContext;
pub use provider::RetryPolicy;
pub use provider::RetryProvider;
pub use provider::Retryable;
pub use provider::StreamEvent;
pub use provider::Usage;
pub use run::Artifact;
pub use run::RunContext;
pub use run::RunMetadata;
pub use run::RunOutput;
pub use run::RunRequest;
pub use run::RunSummary;
pub use run::UserInput;
pub use tool::SharedState;
pub use tool::SideEffectLevel;
pub use tool::Tool;
pub use tool::ToolContext;
pub use tool::ToolError;
pub use tool::ToolMemoryPolicy;
pub use tool::ToolNamespace;
pub use tool::ToolNamespaceKind;
pub use tool::ToolOutput;
pub use tool::ToolPolicy;
pub use tool::ToolResult;
pub use tool::ToolSchema;
pub use tool::ToolSource;
pub use tool::ToolTrustLevel;

Modules

agent
Step-wise agent action protocol shared by runtimes and harnesses.
effect
Effect protocol: side-effect requests and observations.
message
Conversation messages.
observability
Lightweight observability record types.
provider
Provider: the interface for communicating with an LLM.
run
Structured run protocol shared by agent implementations and callers.
tool
Tool: external capabilities an agent can invoke.

Structs

CancellationToken
A token which can be used to signal a cancellation request to one or more tasks.

Attribute Macros

async_trait