Effect protocol: side-effect requests and observations.
Effects are the boundary between an agent kernel and an outer harness.
Tools may parse model arguments into an EffectRequest, but the
request is not executed by the tool itself. A harness or application
runtime classifies, approves, sandboxes, executes, audits, and returns an
EffectObservation for the agent to consume.
Structs
- Display
Output - Output intended for host/UI display.
- Effect
Observation - Observation returned to an agent after an effect request is governed and executed by an outer harness.
- Effect
Output - Output produced by an executed effect.
- Effect
Request - Request for an outer harness to govern and execute a side effect.
- Effect
Source - Source tool call that produced an effect request.
Enums
- Display
Format - Display output format.
- Effect
Kind - Kind of side effect requested by an agent.
- Effect
Status - Terminal status of an executed effect.
- Risk
Level - Request-declared risk level.